@@ -1,3 +1,5 @@
+from typing import Any
+
 # todo: finish a correct float to decimal convertor, because currently, the float_to_decimal that
 #  simply convert the float to a string and load it into a decimal, is limited to 18 decimals
 #  instead of 38, because the string representation of a float will be rounded after 18 decimals.
@@ -31,3 +33,15 @@ from decimal import Decimal
 def float_to_decimal(float_number: float) -> Decimal:
     return Decimal(f"{float_number}")
 
+def float_to_decimal_serializer(item: Any) -> Any:
+    if isinstance(item, dict):
+        for key, value in item.items():
+            item[key] = float_to_decimal_serializer(item=value)
+    elif isinstance(item, list):
+        for i, value in enumerate(item):
+            item[i] = float_to_decimal_serializer(item=value)
+    elif isinstance(item, float):
+        item = float_to_decimal(float_number=item)
+    return item
+
+
